API — satnogs-db 1.19 documentation

# API

SatNOGS DB API is a REST API that provides detailed information about Satellites and Transmitters. This document explains how to use the API to retrieve data for your application.

## Using API Data

API access is open to anyone. All API data are freely distributed under the CC BY-SA license.

## Python API Client

A Python client package is automatically generated for each release. The package is named `satnogs-db-api-client`. This Python client is available in PyPI.

## API Reference

satnogs-db API and SDK Documentation contains a full reference of the API.